K 25
svn:wc:ra_dav:version-url
V 69
/offlineimap/!svn/ver/131/offlineimap/head/offlineimap/folder/Base.py
END
